<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account settings</source>
        <translation type="obsolete">Konto Einstellungen</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="obsolete">Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="obsolete">Kennwort:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>o2 Web2SMS</source>
        <translation type="obsolete">o2 Web2SMS</translation>
    </message>
    <message>
        <source>To:</source>
        <translation type="obsolete">An:</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="obsolete">&amp;Senden</translation>
    </message>
    <message>
        <source>Select provider</source>
        <translation type="obsolete">Anbieter auswählen</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation type="obsolete">Konto Einstellungen</translation>
    </message>
    <message>
        <source>First start notice</source>
        <translation type="obsolete">Erststart Hinweis</translation>
    </message>
    <message>
        <source>This program only works with o2 Germany. Use at your own risk, bugs may be reported on the project website.</source>
        <translation type="obsolete">Dieses Programm funktioniert derzeit nur mit o2 Deutschland. Benutzung auf eigene Gefahr, Fehler können auf der Projekt-Webseite gemeldet werden.</translation>
    </message>
    <message>
        <source>Login failed, please check your username and password</source>
        <translation type="obsolete">Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
    </message>
    <message>
        <source>Logging in ...</source>
        <translation type="obsolete">Anmeldung ...</translation>
    </message>
    <message>
        <source>Feature not implemented on Windows</source>
        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
    <message>
        <source>Logging in</source>
        <translation type="obsolete">Anmeldung ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>Logging out ...</source>
        <translation>Abmeldung ...</translation>
    </message>
    <message>
        <source>Feature not implemented on windows</source>
        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
    <message>
        <source>Choose a contact</source>
        <translation type="obsolete">Wählen Sie einen Kontakt</translation>
    </message>
    <message>
        <source>Sending SMS ...</source>
        <translation type="obsolete">Sende SMS ...</translation>
    </message>
    <message>
        <source>You have %1 free SMS left</source>
        <translation type="obsolete">Sie haben %1 Frei-SMS übrig</translation>
    </message>
</context>
<context>
    <name>MainWindowPrivate</name>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Web2SMS</source>
        <translation>Web2SMS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="90"/>
        <source>Accounts ...</source>
        <translation>Konten ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>Send SMS with %1</source>
        <translation>Sende SMS über %1</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation type="obsolete">Konto Einstellungen</translation>
    </message>
    <message>
        <source>Select provider</source>
        <translation type="obsolete">Anbieter auswählen</translation>
    </message>
    <message>
        <source>Logging in ...</source>
        <translation type="obsolete">Anmeldung ...</translation>
    </message>
    <message>
        <source>Login failed, please check your username and password</source>
        <translation type="obsolete">Anmeldung fehlgeschlagen, bitte überprüfen Sie Ihre Angaben</translation>
    </message>
    <message>
        <source>Currently there is only o2 Germany :(</source>
        <translation type="obsolete">Derzeit steht leider nur o2 Deutschland zur Auswahl :(</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <location filename="../messagewidget.ui" line="14"/>
        <source>Message</source>
        <translation>Nachricht</translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="22"/>
        <source>To:</source>
        <translation>An:</translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="46"/>
        <source>Message type</source>
        <translation>Nachrichtentyp</translation>
    </message>
    <message>
        <location filename="../messagewidget.ui" line="99"/>
        <source>&amp;Send</source>
        <translation>&amp;Senden</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="354"/>
        <source>Logging in ...</source>
        <translation>Anmeldung ...</translation>
    </message>
</context>
<context>
    <name>MessageWidgetPrivate</name>
    <message numerus="yes">
        <source>You have %n free SMS left</source>
        <translation type="obsolete">
            <numerusform>Sie haben eine Frei-SMS übrig</numerusform>
            <numerusform>Sie haben %n Frei-SMS übrig</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="86"/>
        <source>Clear receivers</source>
        <translation>Empfänger zurücksetzen</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="142"/>
        <source>Balance: %1</source>
        <translation>Guthaben: %1</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="185"/>
        <location filename="../messagewidget.cpp" line="187"/>
        <source>Message sent.</source>
        <translation>Nachricht gesendet.</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="199"/>
        <source>Choose a contact</source>
        <translation>Wählen Sie einen Kontakt</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="212"/>
        <source>Wrong number format</source>
        <translation>Falsches Nummernformat</translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="213"/>
        <source>%1&apos;s phone number &quot;%2&quot; could not be converted to an international format.</source>
        <translation>Die Telefonnummer &quot;%2&quot; von %1 konnte nicht in ein internationales Format umgewandelt werden.</translation>
    </message>
    <message numerus="yes">
        <location filename="../messagewidget.cpp" line="242"/>
        <source>The message is too long! This message type only supports %n character(s).</source>
        <translation>
            <numerusform>Die Nachricht ist zu lang! Dieser Nachrichtentyp unterstützt nur ein Zeichen.</numerusform>
            <numerusform>Die Nachricht ist zu lang! Dieser Nachrichtentyp unterstützt nur %n Zeichen.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="250"/>
        <source>This message has no receivers!</source>
        <translation>Die Nachricht hat keine Empfänger!</translation>
    </message>
    <message numerus="yes">
        <location filename="../messagewidget.cpp" line="256"/>
        <source>Too many receivers! This message type only supports %n receiver(s).</source>
        <translation>
            <numerusform>Zu viele Empfänger! Dieser Nachrichtentyp unterstützt nur einen Empfänger.</numerusform>
            <numerusform>Zu viele Empfänger! Dieser Nachrichtentyp unterstützt nur %n Empfänger.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../messagewidget.cpp" line="262"/>
        <source>Sending SMS ...</source>
        <translation>Sende SMS ...</translation>
    </message>
</context>
<context>
    <name>StartWidget</name>
    <message>
        <location filename="../startwidget.ui" line="14"/>
        <source>Web2SMS Startscreen</source>
        <translation>Web2SMS Startbildschirm</translation>
    </message>
    <message>
        <location filename="../startwidget.ui" line="54"/>
        <source>Please select an account for sending a message.
(These can be configured in the settings)</source>
        <translation>Bitte wählen Sie ein Konto, um eine Nachricht zu senden.
(Diese können in den Einstellungen angepasst werden)</translation>
    </message>
</context>
<context>
    <name>contacts_windows</name>
    <message>
        <source>Feature not implemented on Windows</source>
        <translation type="obsolete">Diese Funktion ist unter Windows nicht eingebaut</translation>
    </message>
</context>
<context>
    <name>o2Germany</name>
    <message>
        <source>o2 Germany</source>
        <translation type="obsolete">o2 Deutschland</translation>
    </message>
</context>
<context>
    <name>o2GermanyPrivate</name>
    <message>
        <source>loginForm could not be found!</source>
        <translation type="obsolete">loginForm konnte nicht gefunden werden!</translation>
    </message>
    <message>
        <source>frmSMS could not be found!</source>
        <translation type="obsolete">frmSMS konnte nicht gefunden werden!</translation>
    </message>
    <message>
        <source>HTTP error happened:
%1</source>
        <translation type="obsolete">HTTP Fehler aufgetreten:
%1</translation>
    </message>
</context>
</TS>
